***********************
The sherpa.stats module
***********************

.. currentmodule:: sherpa.stats

.. automodule:: sherpa.stats

   .. rubric:: Classes

   .. autosummary::
      :toctree: api

      Stat
      Chi2
      LeastSq
      Chi2ConstVar
      Chi2DataVar
      Chi2Gehrels
      Chi2ModVar
      Chi2XspecVar
      Likelihood
      Cash
      CStat
      CStatNegativePenalty
      WStat
      UserStat

Class Inheritance Diagram
=========================

.. inheritance-diagram::  Stat Chi2 LeastSq Chi2ConstVar Chi2DataVar Chi2Gehrels Chi2ModVar Chi2XspecVar Likelihood Cash CStat WStat UserStat
   :parts: 1
